@@ -48,13 +48,16 @@ class AppHandler(object):
     default_autocompleters = {
         'brands': 'rattail.autocomplete.brands:BrandAutocompleter',
         'customers': 'rattail.autocomplete.customers:CustomerAutocompleter',
+        'customers.neworder': 'rattail.autocomplete.customers:CustomerNewOrderAutocompleter',
         'customers.phone': 'rattail.autocomplete.customers:CustomerPhoneAutocompleter',
         'employees': 'rattail.autocomplete.employees:EmployeeAutocompleter',
         'departments': 'rattail.autocomplete.departments:DepartmentAutocompleter',
         'people': 'rattail.autocomplete.people:PersonAutocompleter',
         'people.employees': 'rattail.autocomplete.people:PersonEmployeeAutocompleter',
+        'people.neworder': 'rattail.autocomplete.people:PersonNewOrderAutocompleter',
         'products': 'rattail.autocomplete.products:ProductAutocompleter',
         'products.all': 'rattail.autocomplete.products:ProductAllAutocompleter',
+        'products.neworder': 'rattail.autocomplete.products:ProductNewOrderAutocompleter',
         'vendors': 'rattail.autocomplete.vendors:VendorAutocompleter',
     }
 
@@ -63,10 +66,42 @@ class AppHandler(object):
 
     def get_autocompleter(self, key, **kwargs):
         """
-        Returns an Autocompleter instance corresponding to the given
-        key.  Config may determine where the Autocompleter class
-        lives, or there are some defaults registered within the app
-        handler which may be used.
+        Returns a new :class:`~rattail.autocomplete.base.Autocompleter`
+        instance corresponding to the given key, e.g. ``'products'``.
+
+        The app handler has some hard-coded defaults for the built-in
+        autocompleters (see ``default_autocompleters`` in the source
+        code).  You can override any of these, and/or add your own
+        with custom keys, via config, e.g.:
+
+        .. code-block:: ini
+
+           [rattail]
+           autocomplete.products = poser.autocomplete.products:ProductAutocompleter
+           autocomplete.otherthings = poser.autocomplete.things:OtherThingAutocompleter
+
+        With the above you can then fetch your custom autocompleter with::
+
+           autocompleter = app.get_autocompleter('otherthings')
+
+        In any case if it can locate the class, it will create an
+        instance of it and return that.
+
+        :params key: Unique key for the type of autocompleter you
+           need.  Often is a simple string, e.g. ``'customers'`` but
+           sometimes there may be a "modifier" with it to get an
+           autocompleter with more specific behavior.
+
+           For instance ``'customers.phone'`` would effectively give
+           you a customer autocompleter but which searched by phone
+           number instead of customer name.
+
+           Note that each key is still a simple string though, and that
+           must be "unique" in the sense that only one autocompleter
+           can be configured for each key.
+
+        :returns: An :class:`~rattail.autocomplete.base.Autocompleter`
+           instance if found, otherwise ``None``.
         """
         spec = self.config.get('rattail', 'autocomplete.{}'.format(key))
         if not spec:
@@ -76,6 +111,14 @@ class AppHandler(object):
 
         raise NotImplementedError("cannot locate autocompleter for key: {}".format(key))
 
+    def get_auth_handler(self, **kwargs):
+        if not hasattr(self, 'auth_handler'):
+            spec = self.config.get('rattail', 'auth.handler',
+                                   default='rattail.auth:AuthHandler')
+            factory = load_object(spec)
+            self.auth_handler = factory(self.config, **kwargs)
+        return self.auth_handler
+
     def get_board_handler(self, **kwargs):
         if not hasattr(self, 'board_handler'):
             from rattail.board import get_board_handler
