@@ -93,6 +93,18 @@ class CustomerOrderBatchHandler(BatchHandler):
                                    'new_orders.restrict_contact_info',
                                    default=False)
 
+    def product_price_may_be_questionable(self):
+        """
+        Returns a boolean indicating whether "any" product's price may
+        be questionable.  So this isn't saying that a price *is*
+        questionable but rather that it *may* be, if the user
+        indicates it.  (That checkbox is only shown for the user if
+        this flag is true.)
+        """
+        return self.config.getbool('rattail.custorders',
+                                   'product_price_may_be_questionable',
+                                   default=False)
+
     def assign_contact(self, batch, customer=None, person=None, **kwargs):
         """
         Assign the customer and/or person "contact" for the order.
@@ -386,6 +398,68 @@ class CustomerOrderBatchHandler(BatchHandler):
                                   "{}.custom_product_autocomplete() "
                                   "method.".format(__class__.__name__))
 
+    def get_product_info(self, batch, product, **kwargs):
+        """
+        Return a data dict containing misc. info pertaining to the
+        given product, for the order batch.
+        """
+        products = self.app.get_products_handler()
+        info = {
+            'uuid': product.uuid,
+            'upc': six.text_type(product.upc),
+            'upc_pretty': product.upc.pretty(),
+            'unit_price_display': products.render_price(product.regular_price),
+            'full_description': product.full_description,
+            'image_url': products.get_image_url(product),
+            'uom_choices': self.uom_choices_for_product(product),
+        }
+
+        key = self.config.product_key()
+        if key == 'upc':
+            info['key'] = info['upc_pretty']
+        else:
+            info['key'] = getattr(product, key, info['upc_pretty'])
+
+        return info
+
+    def uom_choices_for_product(self, product):
+        """
+        Return a list of UOM choices for the given product.
+        """
+        choices = []
+
+        # Each
+        if not product or not product.weighed:
+            unit_name = self.enum.UNIT_OF_MEASURE[self.enum.UNIT_OF_MEASURE_EACH]
+            choices.append({'key': self.enum.UNIT_OF_MEASURE_EACH,
+                            'value': unit_name})
+
+        # Pound
+        if not product or product.weighed:
+            unit_name = self.enum.UNIT_OF_MEASURE[self.enum.UNIT_OF_MEASURE_POUND]
+            choices.append({
+                'key': self.enum.UNIT_OF_MEASURE_POUND,
+                'value': unit_name,
+            })
+
+        # Case
+        case_text = None
+        case_size = self.get_case_size_for_product(product)
+        if case_size is None:
+            case_text = "{} (&times; ?? {})".format(
+                self.enum.UNIT_OF_MEASURE[self.enum.UNIT_OF_MEASURE_CASE],
+                unit_name)
+        elif case_size > 1:
+            case_text = "{} (&times; {} {})".format(
+                self.enum.UNIT_OF_MEASURE[self.enum.UNIT_OF_MEASURE_CASE],
+                self.app.render_quantity(case_size),
+                unit_name)
+        if case_text:
+            choices.append({'key': self.enum.UNIT_OF_MEASURE_CASE,
+                            'value': case_text})
+
+        return choices
+
     def why_not_add_product(self, product, batch):
         """
         This method can inspect the given product, and batch, to
