@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -63,6 +63,40 @@ class Role(Base):
     Any arbitrary notes for the role.
     """)
 
+    sync_me = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating that this Role (and its user-ship, and
+    permissions) should be synced across all nodes.
+
+    So if set, when the role changes at one node that change should
+    propagate to all other nodes.  This includes "proper" changes e.g.
+    to the role name, but also when any users are added to or removed
+    from the role, that fact also should propagate.  Additionally,
+    when permissions are granted to or revoked from the role, that
+    should propagate.
+
+    See also :attr:`node_type`.
+    """)
+
+    node_type = sa.Column(sa.String(length=100), nullable=True, doc="""
+    Type of node for which this role is applicable.  This is probably
+    only useful if the :attr:`sync_me` flag is set.
+
+    If set, this value must match a node's configured type, or else it
+    will be ignored by that node.  See also
+    :meth:`~rattail.config.RattailConfig.node_type()`.  If there is no
+    value set for this field then the role will be honored by all
+    nodes in which it exists (which is just one unless ``sync_me`` is
+    set, in which case all nodes would have it).
+
+    It is useful in combination with ``sync_me`` in that it allows a
+    certain role to be "global" (synced) and yet only be "effective"
+    for certain nodes.  Probably the most common scenario is where you
+    have a host node and several store nodes, and you want to manage
+    the store roles "globally" but avoid granting unwanted access to
+    the host node.  So you'd set the ``sync_me`` flag but also set
+    ``node_type`` to e.g. ``'store'``.
+    """)
+
     def __str__(self):
         return self.name or ''
 
