@@ -149,6 +149,18 @@ class rattail_custorders_new_orders_restrict_contact_info(Setting):
     name = 'new_orders.restrict_contact_info'
     data_type = bool
 
+class rattail_custorders_product_price_may_be_questionable(Setting):
+    """
+    If set, then user may indicate that the price for a given product
+    is "questionable" - which normally would cause a new step in the
+    workflow, for someone to update and/or confirm the price.  If
+    *not* set then user cannot mark any price as questionable.
+    """
+    group = "Customer Orders"
+    namespace = 'rattail.custorders'
+    name = 'product_price_may_be_questionable'
+    data_type = bool
+
 
 ##############################
 # DataSync
