@@ -165,7 +165,8 @@ class TransactionItemImporter(ToTrainwreck):
             if 'transaction_system_id' in self.key:
                 system_id = host_data['transaction_system_id']
                 txn = self.get_transaction_by_system_id(system_id)
-                assert txn
+                if not txn:
+                    raise RuntimeError("transaction not found for system_id: {}".format(system_id))
                 item.transaction = txn
 
             return item
